@@ -37,6 +37,11 @@ import java.util.List;
 @ThreadSafe
 abstract public class ModelCreators {
 
+    public static <T> Builder serviceInstance(ModelReference<T> modelReference, T instance) {
+        return bridgedInstance(modelReference, instance)
+            .service(true);
+    }
+
     public static <T> Builder bridgedInstance(ModelReference<T> modelReference, T instance) {
         return unmanagedInstance(modelReference, Factories.constant(instance), Actions.doNothing());
     }
@@ -72,9 +77,7 @@ abstract public class ModelCreators {
     }
 
     public static Builder of(ModelPath path, NodeInitializer initializer) {
-        return of(path)
-            .action(ModelActionRole.Create, initializer)
-            .withProjections(initializer.getProjections());
+        return new Builder(path, initializer);
     }
 
     public static Builder of(ModelPath path, ModelReference<?> input, BiAction<? super MutableModelNode, ? super List<ModelView<?>>> initializer) {
@@ -106,13 +109,20 @@ abstract public class ModelCreators {
         private final ModelPath path;
         private final List<ModelProjection> projections = new ArrayList<ModelProjection>();
         private final ListMultimap<ModelActionRole, ModelAction> actions = ArrayListMultimap.create();
+        private final NodeInitializer nodeInitializer;
+        private boolean service;
         private boolean ephemeral;
         private boolean hidden;
 
         private ModelRuleDescriptor modelRuleDescriptor;
 
         private Builder(ModelPath path) {
+            this(path, null);
+        }
+
+        private Builder(ModelPath path, NodeInitializer nodeInitializer) {
             this.path = path;
+            this.nodeInitializer = nodeInitializer;
         }
 
         public Builder descriptor(String descriptor) {
@@ -155,22 +165,6 @@ abstract public class ModelCreators {
             return this;
         }
 
-        public Builder action(ModelActionRole role, final NodeInitializer initializer) {
-            this.action(role, new BuilderModelAction() {
-                @Override
-                public void execute(MutableModelNode modelNode, List<ModelView<?>> inputs) {
-                    initializer.execute(modelNode, inputs);
-                }
-
-                @Override
-                public List<? extends ModelReference<?>> getInputs() {
-                    return initializer.getInputs();
-                }
-            });
-            this.projections.addAll(initializer.getProjections());
-            return this;
-        }
-
         public Builder action(ModelActionRole role, ModelReference<?> input, BiAction<? super MutableModelNode, ? super List<ModelView<?>>> initializer) {
             this.action(role, Collections.singletonList(input), initializer);
             return this;
@@ -197,13 +191,6 @@ abstract public class ModelCreators {
             return this;
         }
 
-        public Builder withProjections(Iterable<? extends ModelProjection> projections) {
-            for (ModelProjection projection : projections) {
-                withProjection(projection);
-            }
-            return this;
-        }
-
         public Builder hidden(boolean flag) {
             this.hidden = flag;
             return this;
@@ -214,9 +201,34 @@ abstract public class ModelCreators {
             return this;
         }
 
+        public Builder service(boolean flag) {
+            this.service = flag;
+            return this;
+        }
+
         @SuppressWarnings("unchecked")
         public ModelCreator build() {
-            return new ProjectionBackedModelCreator(path, modelRuleDescriptor, ephemeral, hidden, projections, actions);
+            if (nodeInitializer != null) {
+                this.action(ModelActionRole.Create, new BuilderModelAction() {
+                    @Override
+                    public void execute(MutableModelNode modelNode, List<ModelView<?>> inputs) {
+                        nodeInitializer.execute(modelNode, inputs);
+                    }
+
+                    @Override
+                    public List<? extends ModelReference<?>> getInputs() {
+                        return nodeInitializer.getInputs();
+                    }
+                });
+
+                this.projections.addAll(nodeInitializer.getProjections());
+
+                ModelAction projector = nodeInitializer.getProjector(path, modelRuleDescriptor);
+                if (projector != null) {
+                    action(ModelActionRole.DefineProjections, projector);
+                }
+            }
+            return new ProjectionBackedModelCreator(path, modelRuleDescriptor, service, ephemeral, hidden || service, projections, actions);
         }
 
         private abstract class BuilderModelAction implements ModelAction {
