@@ -16,16 +16,15 @@
 
 package org.gradle.model.internal.core;
 
-import org.gradle.internal.service.Service;
-import org.gradle.model.internal.manage.schema.ModelSchema;
 import org.gradle.model.internal.manage.schema.extract.NodeInitializerExtractionStrategy;
 import org.gradle.model.internal.type.ModelType;
 
-@Service
 public interface NodeInitializerRegistry {
-    <T> NodeInitializer getNodeInitializer(ModelType<T> type);
+    NodeInitializer getNodeInitializer(NodeInitializerContext nodeInitializerContext);
 
-    <T> NodeInitializer getNodeInitializer(ModelSchema<T> schema);
+    void ensureHasInitializer(NodeInitializerContext nodeInitializer);
 
     void registerStrategy(NodeInitializerExtractionStrategy strategy);
+
+    <T> boolean hasNodeInitializer(ModelType<T> type);
 }
