@@ -19,8 +19,16 @@ package org.gradle.api.internal.jvm;
 import org.gradle.jvm.internal.AbstractJvmBinaryRenderer;
 import org.gradle.api.tasks.diagnostics.internal.text.TextReportBuilder;
 import org.gradle.jvm.ClassDirectoryBinarySpec;
+import org.gradle.model.internal.manage.schema.ModelSchemaStore;
+
+import javax.inject.Inject;
 
 public class ClassDirectoryBinaryRenderer extends AbstractJvmBinaryRenderer<ClassDirectoryBinarySpec> {
+    @Inject
+    public ClassDirectoryBinaryRenderer(ModelSchemaStore schemaStore) {
+        super(schemaStore);
+    }
+
     @Override
     public Class<ClassDirectoryBinarySpec> getTargetType() {
         return ClassDirectoryBinarySpec.class;
